from django.contrib import admin
from .models import *


# we do not add admins, this has to be done inside the project
#admin.site.register(LinearTax, admin.ModelAdmin)
#admin.site.register(MultiTax, admin.ModelAdmin)

